@@ -5,7 +5,7 @@
  * Copyright (C) 2005 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -69,6 +69,11 @@ struct _EBookBackendFilePrivate {
 	DB       *file_db;
 	DB_ENV   *env;
 	EBookBackendSummary *summary;
+	/* for future use */
+	void *reserved1;
+	void *reserved2;
+	void *reserved3;
+	void *reserved4;
 };
 
 static GStaticMutex global_env_lock = G_STATIC_MUTEX_INIT;
@@ -128,6 +133,8 @@ build_summary (EBookBackendFilePrivate *bfpriv)
 		db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_NEXT);
 
 	}
+
+	dbc->c_close (dbc);
 }
 
 static char *
@@ -145,10 +152,10 @@ set_revision (EContact *contact)
 {
 	char time_string[25] = {0};
 	const struct tm *tm = NULL;
-	struct timeval tv;
+	GTimeVal tv;
 
-	if (!gettimeofday (&tv, NULL))
-		tm = gmtime (&tv.tv_sec);
+	g_get_current_time (&tv);
+	tm = gmtime (&tv.tv_sec);
 	if (tm)
 		strftime (time_string, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
 	e_contact_set (contact, E_CONTACT_REV, time_string);
@@ -450,6 +457,11 @@ e_book_backend_file_get_contact_list (EBookBackendSync *backend,
 		status = db_error != DB_NOTFOUND
 			? GNOME_Evolution_Addressbook_OtherError
 			: GNOME_Evolution_Addressbook_Success;
+
+		db_error = dbc->c_close(dbc);
+		if (db_error != 0) {
+			g_warning("Could not close cursor: %d", db_error);
+		}
 	}
 
 	*contacts = contact_list;
@@ -534,7 +546,6 @@ book_view_thread (gpointer data)
 
 		for (i = 0; i < ids->len; i ++) {
 			char *id = g_ptr_array_index (ids, i);
-			printf ("**** id %s\n", id);
 			g_mutex_lock (closure->mutex);
 			stopped = closure->stopped;
 			g_mutex_unlock (closure->mutex);
@@ -572,32 +583,39 @@ book_view_thread (gpointer data)
 		memset (&vcard_dbt, 0, sizeof (vcard_dbt));
 
 		db_error = db->cursor (db, NULL, &dbc, 0);
+		if (db_error == 0) {
 
-		db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_FIRST);
-		while (db_error == 0) {
+			db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_FIRST);
+			while (db_error == 0) {
 
-			g_mutex_lock (closure->mutex);
-			stopped = closure->stopped;
-			g_mutex_unlock (closure->mutex);
+				g_mutex_lock (closure->mutex);
+				stopped = closure->stopped;
+				g_mutex_unlock (closure->mutex);
 
-			if (stopped)
-				break;
+				if (stopped)
+					break;
 
-			/* don't include the version in the list of cards */
-			if (strcmp (id_dbt.data, E_BOOK_BACKEND_FILE_VERSION_NAME)) {
-				EContact *contact = create_contact (id_dbt.data, vcard_dbt.data);
-				/* notify_update will check if it matches for us */
-				e_data_book_view_notify_update (book_view, contact);
-				g_object_unref (contact);
+				/* don't include the version in the list of cards */
+				if (strcmp (id_dbt.data, E_BOOK_BACKEND_FILE_VERSION_NAME)) {
+					EContact *contact = create_contact (id_dbt.data, vcard_dbt.data);
+					/* notify_update will check if it matches for us */
+					e_data_book_view_notify_update (book_view, contact);
+					g_object_unref (contact);
+				}
+
+				db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_NEXT);
 			}
 
-			db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_NEXT);
+			dbc->c_close (dbc);
+			if (db_error != DB_NOTFOUND)
+				g_warning ("e_book_backend_file_search: error building list\n");
+		}
+		else if (db_error == DB_RUNRECOVERY) {
+			g_warning ("e_book_backend_file_search: error getting the cursor for %s\n",
+				   bf->priv->filename);
+			abort ();
 		}
 
-		dbc->c_close (dbc);
-
-		if (db_error != DB_NOTFOUND)
-			g_warning ("e_book_backend_file_search: error building list\n");
 
 	}
 
@@ -605,6 +623,7 @@ book_view_thread (gpointer data)
 		e_data_book_view_notify_complete (book_view, GNOME_Evolution_Addressbook_Success);
 
 	/* unref the */
+	printf("book_view file uref \n");
 	bonobo_object_unref (book_view);
 
 	d(printf ("finished population of book view\n"));
@@ -1042,6 +1061,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 	db_error = e_db3_utils_maybe_recover (filename);
 	if (db_error != 0) {
 		g_warning ("db recovery failed with %d", db_error);
+		g_free (dirname);
+		g_free (filename);
 		return GNOME_Evolution_Addressbook_OtherError;
 	}
 
@@ -1054,6 +1075,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		if (db_error != 0) {
 			g_warning ("db_env_create failed with %d", db_error);
 			g_static_mutex_unlock(&global_env_lock);
+			g_free (dirname);
+			g_free (filename);
 			return GNOME_Evolution_Addressbook_OtherError;
 		}
 
@@ -1062,6 +1085,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 			env->close(env, 0);
 			g_warning ("db_env_open failed with %d", db_error);
 			g_static_mutex_unlock(&global_env_lock);
+			g_free (dirname);
+			g_free (filename);
 			return GNOME_Evolution_Addressbook_OtherError;
 		}
 
@@ -1077,6 +1102,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 	db_error = db_create (&db, env, 0);
 	if (db_error != 0) {
 		g_warning ("db_create failed with %d", db_error);
+		g_free (dirname);
+		g_free (filename);
 		return GNOME_Evolution_Addressbook_OtherError;
 	}
 
@@ -1087,6 +1114,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 
 		if (db_error != 0) {
 			g_warning ("db format upgrade failed with %d", db_error);
+			g_free (dirname);
+			g_free (filename);
 			return GNOME_Evolution_Addressbook_OtherError;
 		}
 
@@ -1108,6 +1137,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 			rv = e_util_mkdir_hier (dirname, 0777);
 			if (rv == -1 && errno != EEXIST) {
 				g_warning ("failed to make directory %s: %s", dirname, strerror (errno));
+				g_free (dirname);
+				g_free (filename);
 				if (errno == EACCES || errno == EPERM)
 					return GNOME_Evolution_Addressbook_PermissionDenied;
 				else
@@ -1134,6 +1165,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 
 	if (db_error != 0) {
 		bf->priv->file_db = NULL;
+		g_free (dirname);
+		g_free (filename);
 		return GNOME_Evolution_Addressbook_OtherError;
 	}
 
@@ -1141,6 +1174,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		db->close (db, 0);
 		bf->priv->file_db = NULL;
 		g_warning ("e_book_backend_file_maybe_upgrade_db failed");
+		g_free (dirname);
+		g_free (filename);
 		return GNOME_Evolution_Addressbook_OtherError;
 	}
 
