@@ -7,15 +7,15 @@
  * Copyright 2003, Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -212,6 +212,11 @@ populate_cache (ECalBackendGroupwise *cbgw)
 
 	return E_GW_CONNECTION_STATUS_OK;
 }
+static gboolean
+compare_prefix (gconstpointer a, gconstpointer b)
+{
+	return !(g_str_has_prefix ((const char *)a, (const char *)b));
+}
 
 static gboolean
 get_deltas (gpointer handle)
@@ -225,8 +230,6 @@ get_deltas (gpointer handle)
 	GList *item_list, *total_list = NULL, *l;
 	GSList *cache_keys = NULL;
 	GPtrArray *uid_array = g_ptr_array_new ();
-
-	char *comp_str;
 	char *time_string = NULL;
 	char t_str [100]; 
 	const char *serv_time;
@@ -469,49 +472,24 @@ get_deltas (gpointer handle)
 
 	for (l = total_list; l != NULL; l = l->next) {
 		EGwItemCalId *calid = (EGwItemCalId *)	l->data;
+		GCompareFunc func = NULL;
+		GSList *remove = NULL;
 
+		if (calid->ical_id) 
+			func = (GCompareFunc) strcmp;
+		else
+			func = (GCompareFunc) compare_prefix;
 
-		if (calid->ical_id) {
-			if (!g_slist_find_custom (cache_keys, calid->ical_id, (GCompareFunc) strcmp)) {
-				g_ptr_array_add (uid_array, g_strdup (calid->item_id));
-				needs_to_get = TRUE;
-			} else  {
-				continue;
-			}
+		if (!(remove = g_slist_find_custom (cache_keys, calid->ical_id ? calid->ical_id :
+						calid->recur_key,  func))) {
+			g_ptr_array_add (uid_array, g_strdup (calid->item_id));
+			needs_to_get = TRUE;
+		} else  {
+			cache_keys = g_slist_delete_link (cache_keys, remove);
+			continue;
 		}
 
-		if (calid->recur_key) {
-			GSList *comp_list = e_cal_backend_cache_get_components_by_uid (priv->cache, calid->recur_key);			
-			if (!comp_list) {
-				g_ptr_array_add (uid_array, g_strdup (calid->item_id));
-				needs_to_get = TRUE;
-			} else {
-				/* There may be one instance added to an existing recurring appointment */
-				GSList *l;
-				gboolean found = FALSE;
-
-				for (l = comp_list; l !=NULL; l = l->next) {
-					ECalComponent *comp = E_CAL_COMPONENT (l->data);	
-
-					if (g_str_equal (calid->item_id, e_cal_component_get_gw_id (comp))) {
-						found = TRUE;
-						break;
-					}
-				}
-
-				if (comp_list) {
-					g_slist_foreach (comp_list, (GFunc)g_object_unref, NULL);
-					comp_list = NULL;
-				}
-
-				if (!found) {
-					needs_to_get = TRUE;
-					g_ptr_array_add (uid_array, g_strdup (calid->item_id));
-				}
-			}
-		}
-
-	}	
+	}
 
 	if (needs_to_get) {
 		e_gw_connection_get_items_from_ids (priv->cnc,
@@ -715,10 +693,10 @@ static ECalBackendSyncStatus
 set_container_id_with_count (ECalBackendGroupwise *cbgw) 
 {
 	ECalBackendGroupwisePrivate *priv;
-	EGwContainer *our_container;
 	GList *container_list = NULL, *l;
 	EGwConnectionStatus status;
 	icalcomponent_kind kind;
+	ECalBackendSyncStatus res;
 
 	priv = cbgw->priv;
 
@@ -742,22 +720,22 @@ set_container_id_with_count (ECalBackendGroupwise *cbgw)
 	if (status != E_GW_CONNECTION_STATUS_OK)
 		return GNOME_Evolution_Calendar_OtherError;
 
+	res =  GNOME_Evolution_Calendar_ObjectNotFound;
 	for (l = container_list; l != NULL; l = l->next) {
 		EGwContainer *container = E_GW_CONTAINER (l->data);
 		const char *name = e_gw_container_get_name (container);
 		
 		if (name && strcmp (name, "Calendar") == 0) {
-			our_container = container;
+			priv->container_id = g_strdup (e_gw_container_get_id (container));
+			priv->total_count = e_gw_container_get_total_count (container);
+			res = GNOME_Evolution_Calendar_Success;
 			break;
 		}
 	}
 
-	priv->container_id = g_strdup (e_gw_container_get_id (our_container));
-	priv->total_count = e_gw_container_get_total_count (our_container);
-
 	e_gw_connection_free_container_list (container_list);
 
-	return GNOME_Evolution_Calendar_Success;
+	return res;
 }
 	
 static ECalBackendSyncStatus
@@ -768,7 +746,7 @@ connect_to_server (ECalBackendGroupwise *cbgw)
 	ESource *source;
 	const char *use_ssl;
 	char *http_uri;
-	int permissions, flag;
+	int permissions;
 	GThread *thread;
 	GError *error = NULL;
 	char *parent_user = NULL;
@@ -1041,21 +1019,21 @@ e_cal_backend_groupwise_get_alarm_email_address (ECalBackendSync *backend, EData
 static ECalBackendSyncStatus
 e_cal_backend_groupwise_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
 {
-	*capabilities = g_strdup (CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS "," \
-				  CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY "," \
-				  CAL_STATIC_CAPABILITY_REMOVE_ALARMS ","   \
-	                          CAL_STATIC_CAPABILITY_NO_THISANDPRIOR "," \
-				  CAL_STATIC_CAPABILITY_NO_THISANDFUTURE "," \
-				  CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK "," \
-				  CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR "," \
-				  CAL_STATIC_CAPABILITY_REQ_SEND_OPTIONS "," \
-				  CAL_STATIC_CAPABILITY_SAVE_SCHEDULES "," \
-				  CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT "," \
-				  CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED "," \
-				  CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY "," \
-				  CAL_STATIC_CAPABILITY_NO_ORGANIZER "," \
-				  CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER "," \
-				  CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING "," \ 
+	*capabilities = g_strdup (CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS ","
+				  CAL_STATIC_CAPABILITY_ONE_ALARM_ONLY ","
+				  CAL_STATIC_CAPABILITY_REMOVE_ALARMS ","
+	                          CAL_STATIC_CAPABILITY_NO_THISANDPRIOR ","
+				  CAL_STATIC_CAPABILITY_NO_THISANDFUTURE ","
+				  CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK ","
+				  CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR ","
+				  CAL_STATIC_CAPABILITY_REQ_SEND_OPTIONS ","
+				  CAL_STATIC_CAPABILITY_SAVE_SCHEDULES ","
+				  CAL_STATIC_CAPABILITY_ORGANIZER_MUST_ACCEPT ","
+				  CAL_STATIC_CAPABILITY_DELEGATE_SUPPORTED ","
+				  CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY ","
+				  CAL_STATIC_CAPABILITY_NO_ORGANIZER ","
+				  CAL_STATIC_CAPABILITY_RECURRENCES_NO_MASTER ","
+				  CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING ","
 				  CAL_STATIC_CAPABILITY_SAVE_SCHEDULES);
 
 	return GNOME_Evolution_Calendar_Success;
@@ -1839,12 +1817,13 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 			return GNOME_Evolution_Calendar_ObjectNotFound;
 		}
 
-		if (e_cal_backend_groupwise_utils_check_delegate (comp, e_gw_connection_get_user_email (priv->cnc))) {
+		if (e_cal_component_has_attendees (comp) && 
+				e_cal_backend_groupwise_utils_check_delegate (comp, e_gw_connection_get_user_email (priv->cnc))) {
 			const char *id = NULL, *recur_key = NULL;
 			
 			item = e_gw_item_new_for_delegate_from_cal (cbgw, comp);
 
-			if (mod == CALOBJ_MOD_ALL) {
+			if (mod == CALOBJ_MOD_ALL && e_cal_component_is_instance (comp)) {
 				recur_key = uid;
 			} else {
 				id = e_gw_item_get_id (item);
@@ -2150,7 +2129,6 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 	if (e_cal_component_has_attachments (comp))
 		fetch_attachments (cbgw, comp);
 
-	modif_comp = comp;
 	status = e_gw_connection_send_appointment (cbgw, priv->container_id, comp, method, &remove, &modif_comp);
 
 	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
@@ -2171,12 +2149,16 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 				e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbgw), uid, e_cal_component_get_as_string (comp), NULL);
 		}
 		else {
-			char *cache_comp = NULL, *temp, *new_comp = NULL;
+			char *cache_comp = NULL, *uid, *new_comp = NULL;
 			ECalComponent *cache_component;
 			
-			e_cal_component_commit_sequence (modif_comp);
-			e_cal_component_get_uid (modif_comp, (const char **) &temp);	
-			cache_component = e_cal_backend_cache_get_component (priv->cache, temp, NULL);
+			if (!modif_comp)
+				modif_comp = g_object_ref (comp);
+			else
+				e_cal_component_commit_sequence (modif_comp);
+
+			e_cal_component_get_uid (modif_comp, (const char **) &uid);	
+			cache_component = e_cal_backend_cache_get_component (priv->cache, uid, NULL);
 			
 			if (cache_component) {
 				e_cal_component_commit_sequence (cache_component);
@@ -2184,7 +2166,6 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 			}
 
 			e_cal_backend_cache_put_component (priv->cache, modif_comp);	
-			e_cal_component_commit_sequence (modif_comp);
 			new_comp = e_cal_component_get_as_string (modif_comp);
 
 			if (cache_comp)
@@ -2194,7 +2175,7 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 				
 			g_free (cache_comp);
 			g_free (new_comp);
-			g_free (temp);
+			g_object_unref (modif_comp);
 		}
 		g_object_unref (comp);	
 		return GNOME_Evolution_Calendar_Success;
