@@ -8,15 +8,15 @@
  *          Rodrigo Moya <rodrigo@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -90,6 +90,8 @@ struct _ECalBackendClass {
 	void (* get_object) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);	
 	void (* get_object_list) (ECalBackend *backend, EDataCal *cal, const char *sexp);
 
+	void (* get_attachment_list) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);	
+	
 	/* Timezone related virtual methods */
 	void (* get_timezone) (ECalBackend *backend, EDataCal *cal, const char *tzid);
 	void (* add_timezone) (ECalBackend *backend, EDataCal *cal, const char *object);
@@ -143,6 +145,8 @@ void e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal);
 void e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);
 void e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *sexp);
 
+void e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);
+
 gboolean e_cal_backend_is_loaded (ECalBackend *backend);
 
 void e_cal_backend_start_query (ECalBackend *backend, EDataCalView *query);
@@ -173,6 +177,11 @@ void e_cal_backend_notify_mode      (ECalBackend *backend,
 void e_cal_backend_notify_auth_required (ECalBackend *backend);
 void e_cal_backend_notify_error     (ECalBackend *backend, const char *message);
 
+void e_cal_backend_notify_view_done (ECalBackend *backend, GNOME_Evolution_Calendar_CallStatus status);
+void e_cal_backend_notify_view_progress (ECalBackend *backend, const char *message, int percent);
+void e_cal_backend_notify_readonly (ECalBackend *backend, gboolean read_only);
+void e_cal_backend_notify_cal_address (ECalBackend *backend, char *address);
+
 
 
 G_END_DECLS
