@@ -2,7 +2,7 @@
   FILE: icalvcal.c
   CREATOR: eric 25 May 00
   
-  $Id: icalvcal.c,v 1.6 2003/10/21 18:28:14 ettore Exp $
+  $Id: icalvcal.c,v 1.8 2005/08/24 02:32:23 zucchi Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -195,7 +195,6 @@ static void icalvcal_traverse_objects(VObject *object,
 	   icalproperty_set_x_name(prop,name);
 	   icalcomponent_add_property(last_comp,prop);
 	} else {
-	    assert(0);
 	    return;
 	}
 
@@ -1010,7 +1009,7 @@ static char* rrule_parse_weekly_days (char *s,
 	return NULL;
 
     for (i = 0; i < ICAL_BY_DAY_SIZE; i++) {
-	char *e;
+	char *e = s;
 	int found_day, day;
 
 	found_day = -1;
@@ -1104,7 +1103,7 @@ static char* rrule_parse_monthly_positions (char *s,
     int occurrences[ICAL_BY_DAY_SIZE];
     int found_weekdays[7] = { 0 };
     int i, num_positions, elems, month_position, day;
-    int num_weekdays, only_weekday;
+    int num_weekdays, only_weekday = 0;
     char *e;
 
     /* If we've already found an error, just return. */
@@ -1144,7 +1143,7 @@ static char* rrule_parse_monthly_positions (char *s,
 
     /* Now read the weekdays in. */
     for (;;) {
-	char *e;
+	char *e = s;
 	int found_day, day;
 
 	found_day = -1;
@@ -1313,10 +1312,7 @@ static char* rrule_parse_yearly_days (char *s,
 void* rule_prop(int icaltype, VObject *object, icalcomponent *comp,
 		icalvcal_defaults *defaults)
 {
-    icalproperty_kind kind = (icalproperty_kind)icaltype;
     icalproperty *prop = NULL;
-    icalvalue *value;
-    icalvalue_kind value_kind;
     char *s, *p, *error_message = NULL;
     const char *property_name;
     int free_string;
@@ -1395,7 +1391,7 @@ void* dc_prop(int icaltype, VObject *object, icalcomponent *comp,
     icalproperty *prop; 
     icalvalue *value;
     icalvalue_kind value_kind;
-    char *s,*t=0;
+    char *s;
     int free_string;
 
 
