@@ -6,15 +6,15 @@
  * Copyright 2000-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -1695,7 +1695,7 @@ static CamelObjectMeta *
 co_metadata_get(CamelObject *obj)
 {
 	CamelHookPair *pair;
-	CamelObjectMeta *meta = NULL, *metaout = NULL, *metalast;
+	CamelObjectMeta *meta = NULL, *metaout = NULL, *metalast = NULL;
 
 	pair = co_metadata_pair(obj, FALSE);
 	if (pair) {
@@ -1704,7 +1704,7 @@ co_metadata_get(CamelObject *obj)
 		while (meta) {
 			CamelObjectMeta *m;
 
-			m = g_malloc(sizeof(*metalast) + strlen(meta->name));
+			m = g_malloc(sizeof(*m) + strlen(meta->name));
 			m->next = NULL;
 			strcpy(m->name, meta->name);
 			m->value = g_strdup(meta->value);
