@@ -5,15 +5,15 @@
  * Copyright (C) 2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
@@ -145,8 +145,6 @@ e_name_selector_init (ENameSelector *name_selector)
 static void
 e_name_selector_finalize (GObject *object)
 {
-	ENameSelector *name_selector = E_NAME_SELECTOR (object);
-
 	if (G_OBJECT_CLASS (e_name_selector_parent_class)->finalize)
 		G_OBJECT_CLASS (e_name_selector_parent_class)->finalize (object);
 }
