@@ -7,15 +7,15 @@
  * Copyright 2003, Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -149,6 +149,12 @@ typedef struct {
 	char *thread;
 } EGwItemLinkInfo;
 
+typedef struct {
+	char *item_id;
+	char *ical_id;
+	char *recur_key;
+} EGwItemCalId;
+
 GType       e_gw_item_get_type (void);
 EGwItem    *e_gw_item_new_empty (void);
 EGwItem    *e_gw_item_new_from_soap_parameter (const char *email, const char *container, SoupSoapParameter *param);
@@ -232,6 +238,7 @@ void e_gw_item_set_expires (EGwItem *item, char *expires);
 char *e_gw_item_get_expires (EGwItem *item);
 void e_gw_item_set_delay_until (EGwItem *item, char *delay_until);
 char *e_gw_item_get_delay_until (EGwItem *item);
+void e_gw_item_free_cal_id (EGwItemCalId *calid);
 
 
 #define E_GW_ITEM_CLASSIFICATION_PUBLIC       "Public"
